==> ejc-jltest-impl-3.0.0-20240311.091845-55-sources.jar: com/ejianc/business/jltest/orgtest/bean/PlandEntity.java <==
package com.ejianc.business.jltest.orgtest.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

import com.ejianc.business.jltest.orgtest.bean.PlandDetailEntity;
/**
 * 安措费使用计划D
 * 
 * @author generator
 * 
 */
 @TableName("ejc_jltest_pland")
public class PlandEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="bill_code")
    private String billCode; // 安措费使用计划发文字号
    @TableField(value="safeteamd_id")
    private Long safeteamdId; // 安全小组id
    @TableField(value="safeteamd_name")
    private String safeteamdName; // 安全小组发文名称
    @TableField(value="safeteamd_bill_code")
    private String safeteamdBillCode; // 安全小组发文字号
    @TableField(value="safeteamd_date")
    private Date safeteamdDate; // 安全小组日期
    @TableField(value="plan_name")
    private String planName; // 安措费使用计划发文名称
    @TableField(value="urgency")
    private Integer urgency; // 紧急程度(0-特急,1-急,2-一般)
    @TableField(value="secret_level")
    private Integer secretLevel; // 密级(0-公开,1-秘密,2-机密,3-绝密)
    @TableField(value="plan_date")
    private Date planDate; //  安措费使用计划发文日期
    @TableField(value="proposed_investment_mny")
    private BigDecimal proposedInvestmentMny; // 拟投入金额
    @TableField(value="submit_name")
    private String submitName; // 提交人名称
    @TableField(value="submit_time")
    private Date submitTime; // 提交时间
    @TableField(value="employee_id")
    private Long employeeId; // 经办人
    @TableField(value="employee_name")
    private String employeeName; // 经办人名称
    @TableField(value="department_id")
    private Long departmentId; // 经办部门
    @TableField(value="department_name")
    private String departmentName; // 经办部门名称
    @TableField(value="memo")
    private String memo; // 安措费使用计发文说明
    @TableField(value="project_id")
    private Long projectId; // 项目
    @TableField(value="project_name")
    private String projectName; // 项目名称
    @TableField(value="project_code")
    private String projectCode; // 项目code
    @TableField(value="org_id")
    private Long orgId; // 组织
    @TableField(value="org_name")
    private String orgName; // 组织名称
    @TableField(value="org_code")
    private String orgCode; // 组织code
    @TableField(value="parent_org_name")
    private String parentOrgName; // 父级组织名称
    @TableField(value="parent_org_code")
    private String parentOrgCode; // 父级组织编码
    @TableField(value="parent_org_id")
    private Long parentOrgId; // 父级组织
    @TableField(value="bill_state")
    private Integer billState; // 单据状态（审批必须字段）


    
    @TableField(exist=false)
    @SubEntity(serviceName="plandDetailService",pidName = "plandId")
    private List<PlandDetailEntity> plandDetailList = new ArrayList<>(); // 安措费使用计划D明细


    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }

    public Long getSafeteamdId() {
        return safeteamdId;
    }

    public void setSafeteamdId(Long safeteamdId) {
        this.safeteamdId = safeteamdId;
    }
    public String getSafeteamdName() {
        return safeteamdName;
    }

    public void setSafeteamdName(String safeteamdName) {
        this.safeteamdName = safeteamdName;
    }
    public String getSafeteamdBillCode() {
        return safeteamdBillCode;
    }

    public void setSafeteamdBillCode(String safeteamdBillCode) {
        this.safeteamdBillCode = safeteamdBillCode;
    }
    public Date getSafeteamdDate() {
        return safeteamdDate;
    }

    public void setSafeteamdDate(Date safeteamdDate) {
        this.safeteamdDate = safeteamdDate;
    }
    public String getPlanName() {
        return planName;
    }

    public void setPlanName(String planName) {
        this.planName = planName;
    }
    public Integer getUrgency() {
        return urgency;
    }

    public void setUrgency(Integer urgency) {
        this.urgency = urgency;
    }
    public Integer getSecretLevel() {
        return secretLevel;
    }

    public void setSecretLevel(Integer secretLevel) {
        this.secretLevel = secretLevel;
    }
    public Date getPlanDate() {
        return planDate;
    }

    public void setPlanDate(Date planDate) {
        this.planDate = planDate;
    }
    public BigDecimal getProposedInvestmentMny() {
        return proposedInvestmentMny;
    }

    public void setProposedInvestmentMny(BigDecimal proposedInvestmentMny) {
        this.proposedInvestmentMny = proposedInvestmentMny;
    }
    public String getSubmitName() {
        return submitName;
    }

    public void setSubmitName(String submitName) {
        this.submitName = submitName;
    }
    public Date getSubmitTime() {
        return submitTime;
    }

    public void setSubmitTime(Date submitTime) {
        this.submitTime = submitTime;
    }
    public Long getEmployeeId() {
        return employeeId;
    }

    public void setEmployeeId(Long employeeId) {
        this.employeeId = employeeId;
    }
    public String getEmployeeName() {
        return employeeName;
    }

    public void setEmployeeName(String employeeName) {
        this.employeeName = employeeName;
    }
    public Long getDepartmentId() {
        return departmentId;
    }

    public void setDepartmentId(Long departmentId) {
        this.departmentId = departmentId;
    }
    public String getDepartmentName() {
        return departmentName;
    }

    public void setDepartmentName(String departmentName) {
        this.departmentName = departmentName;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    public String getProjectCode() {
        return projectCode;
    }

    public void setProjectCode(String projectCode) {
        this.projectCode = projectCode;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public String getOrgCode() {
        return orgCode;
    }

    public void setOrgCode(String orgCode) {
        this.orgCode = orgCode;
    }
    public String getParentOrgName() {
        return parentOrgName;
    }

    public void setParentOrgName(String parentOrgName) {
        this.parentOrgName = parentOrgName;
    }
    public String getParentOrgCode() {
        return parentOrgCode;
    }

    public void setParentOrgCode(String parentOrgCode) {
        this.parentOrgCode = parentOrgCode;
    }
    public Long getParentOrgId() {
        return parentOrgId;
    }

    public void setParentOrgId(Long parentOrgId) {
        this.parentOrgId = parentOrgId;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    

    public List<PlandDetailEntity> getPlandDetailList() {
        return plandDetailList;
    }

    public void setPlandDetailList(List<PlandDetailEntity> plandDetailList) {
        this.plandDetailList = plandDetailList;
    }
}

==> ejc-jltest-impl-3.0.0-20240323.031742-97-sources.jar: com/ejianc/business/jltest/orgtest/bean/PlandEntity.java <==
package com.ejianc.business.jltest.orgtest.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

import com.ejianc.business.jltest.orgtest.bean.PlandDetailEntity;
/**
 * 安措费使用计划D
 * 
 * @author generator
 * 
 */
 @TableName("ejc_jltest_pland")
public class PlandEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="bill_code")
    private String billCode; // 安措费使用计划发文字号
    @TableField(value="safeteamd_id")
    private Long safeteamdId; // 安全小组id
    @TableField(value="safeteamd_name")
    private String safeteamdName; // 安全小组发文名称
    @TableField(value="safeteamd_bill_code")
    private String safeteamdBillCode; // 安全小组发文字号
    @TableField(value="safeteamd_date")
    private Date safeteamdDate; // 安全小组日期
    @TableField(value="plan_name")
    private String planName; // 安措费使用计划发文名称
    @TableField(value="urgency")
    private Integer urgency; // 紧急程度(0-特急,1-急,2-一般)
    @TableField(value="secret_level")
    private Integer secretLevel; // 密级(0-公开,1-秘密,2-机密,3-绝密)
    @TableField(value="plan_date")
    private Date planDate; //  安措费使用计划发文日期
    @TableField(value="proposed_investment_mny")
    private BigDecimal proposedInvestmentMny; // 拟投入金额
    @TableField(value="submit_name")
    private String submitName; // 提交人名称
    @TableField(value="submit_time")
    private Date submitTime; // 提交时间
    @TableField(value="employee_id")
    private Long employeeId; // 经办人
    @TableField(value="employee_name")
    private String employeeName; // 经办人名称
    @TableField(value="department_id")
    private Long departmentId; // 经办部门
    @TableField(value="department_name")
    private String departmentName; // 经办部门名称
    @TableField(value="memo")
    private String memo; // 安措费使用计发文说明
    @TableField(value="project_id")
    private Long projectId; // 项目
    @TableField(value="project_name")
    private String projectName; // 项目名称
    @TableField(value="project_code")
    private String projectCode; // 项目code
    @TableField(value="org_id")
    private Long orgId; // 组织
    @TableField(value="org_name")
    private String orgName; // 组织名称
    @TableField(value="org_code")
    private String orgCode; // 组织code
    @TableField(value="parent_org_name")
    private String parentOrgName; // 父级组织名称
    @TableField(value="parent_org_code")
    private String parentOrgCode; // 父级组织编码
    @TableField(value="parent_org_id")
    private Long parentOrgId; // 父级组织
    @TableField(value="bill_state")
    private Integer billState; // 单据状态（审批必须字段）

    @TableField(exist = false)
    private String secretLevelName; //密级翻译

    @TableField(exist = false)
    private String urgencyName; //紧急程度翻译

    public String getSecretLevelName() {
        return secretLevelName;
    }

    public void setSecretLevelName(String secretLevelName) {
        this.secretLevelName = secretLevelName;
    }

    public String getUrgencyName() {
        return urgencyName;
    }

    public void setUrgencyName(String urgencyName) {
        this.urgencyName = urgencyName;
    }

    @TableField(exist=false)
    @SubEntity(serviceName="plandDetailService",pidName = "plandId")
    private List<PlandDetailEntity> plandDetailList = new ArrayList<>(); // 安措费使用计划D明细


    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }

    public Long getSafeteamdId() {
        return safeteamdId;
    }

    public void setSafeteamdId(Long safeteamdId) {
        this.safeteamdId = safeteamdId;
    }
    public String getSafeteamdName() {
        return safeteamdName;
    }

    public void setSafeteamdName(String safeteamdName) {
        this.safeteamdName = safeteamdName;
    }
    public String getSafeteamdBillCode() {
        return safeteamdBillCode;
    }

    public void setSafeteamdBillCode(String safeteamdBillCode) {
        this.safeteamdBillCode = safeteamdBillCode;
    }
    public Date getSafeteamdDate() {
        return safeteamdDate;
    }

    public void setSafeteamdDate(Date safeteamdDate) {
        this.safeteamdDate = safeteamdDate;
    }
    public String getPlanName() {
        return planName;
    }

    public void setPlanName(String planName) {
        this.planName = planName;
    }
    public Integer getUrgency() {
        return urgency;
    }

    public void setUrgency(Integer urgency) {
        this.urgency = urgency;
    }
    public Integer getSecretLevel() {
        return secretLevel;
    }

    public void setSecretLevel(Integer secretLevel) {
        this.secretLevel = secretLevel;
    }
    public Date getPlanDate() {
        return planDate;
    }

    public void setPlanDate(Date planDate) {
        this.planDate = planDate;
    }
    public BigDecimal getProposedInvestmentMny() {
        return proposedInvestmentMny;
    }

    public void setProposedInvestmentMny(BigDecimal proposedInvestmentMny) {
        this.proposedInvestmentMny = proposedInvestmentMny;
    }
    public String getSubmitName() {
        return submitName;
    }

    public void setSubmitName(String submitName) {
        this.submitName = submitName;
    }
    public Date getSubmitTime() {
        return submitTime;
    }

    public void setSubmitTime(Date submitTime) {
        this.submitTime = submitTime;
    }
    public Long getEmployeeId() {
        return employeeId;
    }

    public void setEmployeeId(Long employeeId) {
        this.employeeId = employeeId;
    }
    public String getEmployeeName() {
        return employeeName;
    }

    public void setEmployeeName(String employeeName) {
        this.employeeName = employeeName;
    }
    public Long getDepartmentId() {
        return departmentId;
    }

    public void setDepartmentId(Long departmentId) {
        this.departmentId = departmentId;
    }
    public String getDepartmentName() {
        return departmentName;
    }

    public void setDepartmentName(String departmentName) {
        this.departmentName = departmentName;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    public String getProjectCode() {
        return projectCode;
    }

    public void setProjectCode(String projectCode) {
        this.projectCode = projectCode;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public String getOrgCode() {
        return orgCode;
    }

    public void setOrgCode(String orgCode) {
        this.orgCode = orgCode;
    }
    public String getParentOrgName() {
        return parentOrgName;
    }

    public void setParentOrgName(String parentOrgName) {
        this.parentOrgName = parentOrgName;
    }
    public String getParentOrgCode() {
        return parentOrgCode;
    }

    public void setParentOrgCode(String parentOrgCode) {
        this.parentOrgCode = parentOrgCode;
    }
    public Long getParentOrgId() {
        return parentOrgId;
    }

    public void setParentOrgId(Long parentOrgId) {
        this.parentOrgId = parentOrgId;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    

    public List<PlandDetailEntity> getPlandDetailList() {
        return plandDetailList;
    }

    public void setPlandDetailList(List<PlandDetailEntity> plandDetailList) {
        this.plandDetailList = plandDetailList;
    }
}
